==============================================
``psyclone.psyir.nodes.read_only_verify_node``
==============================================

.. automodule:: psyclone.psyir.nodes.read_only_verify_node

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.nodes.read_only_verify_node


Classes
=======

- :py:class:`ReadOnlyVerifyNode`:
  This class can be inserted into a Schedule to mark Nodes for


.. autoclass:: ReadOnlyVerifyNode
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: ReadOnlyVerifyNode
      :parts: 1
